#
# spec file for package mate-panel
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libmate-panel-applet-4
%define sover   1
%define typelib typelib-1_0-MatePanelApplet-4_0
%define _version 1.20
Name:           mate-panel
Version:        1.20.5
Release:        1.1
Summary:        MATE Desktop Panel
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
Source1:        %{name}-branding.gschema.override.in
Source2:        baselibs.conf
# PATCH-FIX-OPENSUSE mate-panel-layouts-suse.patch sor.alexei@meowr.ru -- Correct missing elements.
Patch0:         mate-panel-layouts-suse.patch
# PATCH-FEATURE-OPENSUSE mate-panel-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch1:         mate-panel-gtk-3.20.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libxml2-python
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  popt-devel
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(NetworkManager)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(dconf) >= 0.13.4
BuildRequires:  pkgconfig(gio-2.0) >= 2.48
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libmate-menu)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(libwnck-3.0)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(mateweather) >= %{_version}
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xrandr) >= 1.3
Requires:       %{name}-branding >= %{version}
Requires:       gsettings-backend-dconf
Requires:       gvfs-backends
Recommends:     %{name}-lang
# Remove old packages.
Obsoletes:      mate-panel-matecomponent-support

%description
This package contains the MATE Desktop Panel. The panel is an
interface to manage the desktop, launch applications, and organise
access to data.

%package branding-upstream
Summary:        Upstream default layout for the MATE desktop panel
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: Provides /usr/share/mate-panel/panel-default-layout.layout
#BRAND: which contains the default layout.
#BRAND: Branding package should require packages with applets in
#BRAND: the default layout.
%glib2_gsettings_schema_requires

%description branding-upstream
This package contains the MATE Desktop Panel. The panel is an
interface to manage the desktop, launch applications, and organise
access to data.

This package contains the upstream default layout for MATE Panel.

%package -n %{soname}-%{sover}
Summary:        MATE Panel Applet Library -- matecomponent-based library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{soname}-%{sover}
This package contains the MATE Desktop Panel. The panel is an
interface to manage the desktop, launch applications, and organise
access to data.

%package -n %{typelib}
Summary:        Introspection bindings for the MATE panel applet library
License:        GPL-2.0-or-later
Group:          System/GUI/Other

%description -n %{typelib}
This package contains the MATE Desktop Panel. The panel is an
interface to manage the desktop, launch applications, and organise
access to data.

%package devel
Summary:        Development files for the MATE panel applet library
License:        GPL-2.0-or-later
Group:          Development/Libraries/Other
Requires:       %{soname}-%{sover} = %{version}
Requires:       %{typelib} = %{version}

%description devel
This package contains the MATE Desktop Panel. The panel is an
interface to manage the desktop, launch applications, and organise
access to data.

%lang_package

%prep
%setup -q
%patch0 -p1
%patch1 -p1
cp -a %{SOURCE1} zz-mate-panel-upream-branding.gschema.override

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-static                    \
  --enable-introspection              \
  --disable-scrollkeeper
make %{?_smp_mflags} V=1

%install
%make_install
mkdir -p %{buildroot}%{_datadir}/mate/
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}%{_datadir}/mate/
%fdupes %{buildroot}%{_datadir}/mate-panel/
%fdupes %{buildroot}%{_includedir}/
%suse_update_desktop_file %{name}

# And install schema override file to get it applied.
mkdir -p %{buildroot}%{_datadir}/glib-2.0/schemas/
install -pm 0644 zz-mate-panel-upream-branding.gschema.override \
  %{buildroot}%{_datadir}/glib-2.0/schemas/

%post -n %{soname}-%{sover} -p /sbin/ldconfig

%postun -n %{soname}-%{sover} -p /sbin/ldconfig

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%icon_theme_cache_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%glib2_gsettings_schema_postun

%post branding-upstream
%glib2_gsettings_schema_post

%postun branding-upstream
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc ChangeLog README
%{_mandir}/man?/mate-panel.?%{?ext_man}
%{_mandir}/man?/mate-panel-test-applets.?%{?ext_man}
%{_mandir}/man?/mate-desktop-item-edit.?%{?ext_man}
%{_bindir}/mate-desktop-item-edit
%{_bindir}/mate-panel
%{_bindir}/mate-panel-test-applets
%{_libexecdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/help/C/
%{_datadir}/icons/hicolor/*/apps/%{name}*
%{_datadir}/%{name}/
# Files from branding-upstream.
%exclude %{_datadir}/glib-2.0/schemas/zz-mate-panel-upream-branding.gschema.override

%files branding-upstream
%{_datadir}/glib-2.0/schemas/zz-mate-panel-upream-branding.gschema.override

%files -n %{soname}-%{sover}
%dir %{_datadir}/mate
%{_libdir}/%{soname}.so.%{sover}*

%files -n %{typelib}
%{_libdir}/girepository-1.0/MatePanelApplet-4.0.typelib

%files devel
%{_includedir}/mate-panel-4.0/
%{_libdir}/pkgconfig/libmatepanelapplet-4.0.pc
%{_libdir}/%{soname}.so
%{_datadir}/gir-1.0/MatePanelApplet-4.0.gir
%{_datadir}/gtk-doc/html/%{name}-applet/

%files lang -f %{name}.lang
%{_datadir}/help/
%exclude %{_datadir}/help/C/

%changelog
* Sat Feb  2 2019 sor.alexei@meowr.ru
- Update to version 1.20.5:
  * Fix a crash on removing tray.
  * Tray: Fix too-wide icon spacing after mate-polkit has been used
    with StatusNotifier.
  * na-tray: Wide panels, convert main GtkBox display to GtkGrid.
  * na-tray: Wide panels, preliminary batch box to grid rename.
  * button-widget: Wide panels, more suitable resize limits on
    Widgets and arrows.
  * clock: Set horizontal padding for clock-button.
  * Clock: Fix weather icon size selection for panel height.
  * Clock: Ensure weather icon resizes with panel.
  * clock: Force no button vertical padding and margin.
  * Update translations.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.4:
  * Disable deprecation warnings for distcheck.
  * Tray: Simplify force-redraw, use code that actually works.
  * Use make functions for HELP_LINGUAS.
  * menu-bar: Transfer focus correctly on alt-F1.
  * Update legal.xml.
  * Clock applet help: To Adjust the System Date or Time.
  * Clock applet help: Add Show week numbers in calendar.
  * Clock applet help: Fix speed unit for meters per second.
  * Add fish and clock help to transifex config.
  * panel: Avoid a critical.
  * panel-toplevel: Fix memory leak in calculate_minimum_height.
  * Update translations.
* Thu Aug  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * Change GTK_CHECK_VERSION to match the next GTK+3 release.
  * applets: Guard against GTK+ scale-factor fixes on GtkSocket.
  * window-list: Skip setting size hints until WnckTasklist has
    items to show.
  * applets: Fix runtime error messages.
  * mate-panel-applet: Setup_x_error_handler for in-process
    applets too.
  * GTK+ 3.23+: Fix applet size allocation.
  * GTK+ 3.23+: Don't cut tray icons too narrow in HiDPI mode.
  * na-tray-child: Remove na_tray_child_size_allocate.
  * Remove a leftover from GTK+2 that may play a role in cutting
    tray icons.
  * panel-toplevel: Add position css class.
  * Update translations.
* Tue Jun  5 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Convert launcher icons to cairo surfaces.
  * Fix rendering and removal of in-process applets on unexpanded
    panel.
  * Limit size of panel-hide-button.
  * clock: Fix copy/paste error which caused use-after-free.
  * fish: Install fish animations in fish-specific directory.
  * fish: Drop wanda image from gresource.
  * css: Use parsing-error signal to warn on bad css file or image.
  * css: Convert to GResource.
  * na-tray: Convert to GResource.
  * wncklet: Convert to GResource.
  * panel: Convert to GResource.
  * clock: Use new GdkPixbuf API to load resources.
  * clock: Convert to GResource.
  * fish: Convert to GResource.
  * libpanel-applet: Add panel_applet_setup_menu_from_resource() API.
  * Theme: Consistant theming for applet drag handles in all themes.
  * Revert "panel-toplevel: Remove pointer boundary check in
    panel_toplevel_queue_auto_hide()"
  * Accessibility: White/black applet handles in GNOME high
    contrast themes.
  * Theme: show applet handles on non-MATE themes.
  * Update translations.
- Rebase mate-panel-gtk-3.20.patch.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * workspace-switcher: Support Metacity and i3 WMs.
  * Fix rendering of out-of-process window list with HiDPI.
  * Apply a fix for workspace-switcher.
  * hidpi: Fix tray icon spacing with window-scaling > 1.
  * Fix out-of-process applet sizes for HiDPI.
  * Fix hide buttons make panel bigger.
  * run-dialog: Force icon size when loading an application icon.
  * run-dialog: Fix expand of content on window resize.
  * Fix run dialogue show-program-list enabling fix.
  * run-dialog: Use F6 to switch between entry field and
    application list.
  * Fix strut sizes for HiDPI multi-monitors.
  * Do not down-scale monitor geometries for GDK monitors.
  * Scale monitor geometries down to device pixels to support
    multiple monitors in HiDPI.
  * Drawer cleanup and fix arrow behaviour.
- Rebase mate-panel-gtk-3.20.patch.
* Wed Mar 14 2018 jengelh@inai.de
- Update summaries. Trim bias and filler wording from descriptions.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * status-notifier: Fix a crash on unknown signal name.
  * Use GTK+3 bookmarks location for Places menu.
  * doc: Remove some references to nonexistent stuff.
  * Run dialogue: Add an option to reverse history view.
  * Run dialogue: Fix wrong history len with max size 1.
  * Run dialogue: Allow changing history size.
  * Run dialogue: Fix wrong history order.
  * status-notifier: Do not hide passive items.
  * panel-menu-bar: Fix a build warning and some spacing.
  * system-tray: Properly propagate orientation changes.
  * workspace switcher: Handle GDK_SCROLL_SMOOTH and fix a build
    warning.
  * status-notifier: Fix handling of the icon-padding style
    property.
  * Simplify the panel description shown when switching panels with
    the WM.
  * status-notifier: Plug a memory leak.
  * status-notifier-watcher: Allow re-registration of registered
    items.
  * Setup a custom icon.
  * status-notifier: Plug a memory leak.
  * menu: Remove incorrect code from the popup menu of a menuitem.
  * status notifier: Follow the same menu theme as the rest of the
    panel.
  * clock: Drop deprecated gtk_size_group_set_ignore_hidden().
  * menu-button, action-button: Disconnect from GSettings when an
    applet is removed.
  * Avoid deprecated gdk_screen_get_number().
  * system tray: Fix hidden icons on image/transparent colour BG.
  * clock: Fix hovering over timezone text, causes panel to scale
    beyond screen limit.
  * wncklet: Stop segfaults, warnings on removing the win-process
    switcher, window-list.
  * fish: Fix adding back after removal.
  * Fish: Stop all warnings on removing when built in-process.
  * Clock: Fix removal warnings when an in-process applet removed.
  * clock: Stop a segfault on removing applet when built in-process.
  * libmate-panel-applet: Fix typos in id->factory_id rename.
  * libmate-panel-applet: Only declare
    _panel_applet_shlib_factory() when needed.
  * libmate-panel-applet: Fix an error in unregistering dbus object.
  * libmate-panel-applet: Fix a build warning.
  * libmate-panel-applet: Fix introspection.
  * libmate-panel-applet: Unown the bus name and unregister the
    D-Bus object.
  * libmate-panel-applet: Include a dummy variable in factory for
    certian applets.
  * libmate-panel-applet: Fix bg rendering for in-process applets.
  * libpanel-applet/panel-applet.h: Rename id to factory_id for
    factory.
  * limatepanel-applet: Add panel-applet-private.h.
  * Don't use GtkPlug/GtkSocket for in process applets.
  * Make it possible to get an applet widget.
  * libpanel-applet: Add panel_applet_factory_get_applet_widget.
  * libpanel-applet: Return process type and applet uid.
  * libpanel-applet: Store factories in hash table.
  * libpanel-applet: Delay GtkPlug creation.
  * libpanel-applet: Add process type to private data.
  * libpanel-applet: Remove out_process from panel_applet_factory_main().
  * Avoid deprecated gdk_screen_get_width/height(),
    gdk_screen_get_n_monitors().
  * fish: Fix applet opening as a thin line when built in-process.
  * Forces a window scale of 1 for the panel instead of using the
    default or user configured scale.
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_make_display_name(), gdk_display_get_screen()
    functions.
  * Don't use deprecated gtk_show_uri().
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Keep the right icons on bottom still displaying right when the
    resolution change larger.
  * wncklet: Disconnect signals by data on destroy.
  * Clock: Don't check variables that can never be < 0 for < 0.
  * status-notifier: Hide mate-polkit icon if passive.
  * Apply a position fix on popup to GTK+ 3.20 and earlier.
  * Stop panel collapse left on adding certain out-of-process
    applets.
  * panel-context-menu: Add confirmation dialogue to the panel
    reset option.
  * Add an option to the context menu to reset the panel.
  * Bump the minimum required libwnck version to 3.4.6.
  * status-notifier: Don't crash if the tooltip has the wrong type.
  * status-notifier: Don't crash if the menu layout has the wrong
    type.
  * Fix rendering of radio buttons in status notifier.
  * panel-run-dialog: Fix a segfault when the application list is
    enabled.
  * Get focus when displaying the "applet broken" dialogue.
  * Update the workspace switcher properties dialogue.
  * Simplify some code.
  * status-notifier: Properly handle the NULL case for items.
  * status-notifier: Handle wrong-size icons called by path.
  * status-notifier: Load icons specified by path.
  * Fix failures to load icons when the application calls for a
    path and not an icon name.
  * Fix a build warning: "toplevel_configure_event" defined but not
    used.
  * Fix a build warning: "GLIB_VERSION_MIN_REQUIRED" redefined.
  * status-notifier: Fix failure to show an icon for missing icon.
  * Spelling: apps, … spaced comma.
  * Support panel auto-scaling for HiDPI displays.
  * Add gir for mate_panel_applet_set_size_hints().
  * panel-stock-icons.c: Fix warnings in ~/.xsession-errors.
  * Fix run dialogue show-program-list enabling.
  * panel-run-dialog: Fix a build warning about incompatible type.
  * workspace-switcher: Restore border width and spacing in the
    Preferences dialogue.
  * context menu: Add a separator before the Reset Panel menu item.
  * background: Reword a warning about an unsupported
    background-image value.
  * Set the "document-properties" icon in "Edit Menus".
  * Update translations.
- Add mate-panel-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20
  support.
* Mon Jan  8 2018 sor.alexei@meowr.ru
- Update to version 1.18.7:
  * panel-toplevel: Remove pointer boundary check in
    panel_toplevel_queue_auto_hide().
  * panel-toplevel: Ensure right aligned icons stay right aligned
    when changing resolutions.
  * status-notifier: Fix failure to show icon for missing icons.
  * panel-plug: Fix a build warning.
  * panel-wdget: FIx a build warning.
  * panel-applet-container: Rework the process of cancelling the
    background change operation.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 1.18.6:
  * status-notifier: Hide the mate-polkit icon if passive.
  * wncklet: Disconnect signal handlers on destroy.
  * Stop segfaults, warnings on removing in-process switcher,
    window-list.
  * clock: Disconnect signal handlers on destroy.
* Wed Nov  8 2017 sor.alexei@meowr.ru
- Update to version 1.18.5:
  * Apply a position fix on popup to GTK+ 3.20 and earlier.
  * GTK+ 3.22 status notifier: Reposition the menu when size
    changes.
  * GTK+ 3.22/status-notifer: Fix menu position if size changed
    since last shown.
  * Fix crashes on moving/removing applets with glib 2.53.4 or
    later.
  * Stop panel collapse left on adding certain out-of-process
    applets.
  * Add a gsettings key to enable/disable SNI Support.
  * Make file/directory launchers work again.
  * Update translations.
* Thu Jul 20 2017 sor.alexei@meowr.ru
- Update to version 1.18.4:
  * Fix GTK+ theme image bg support on vertical panel.
  * Make panel image background in GTK+ theme work again.
  * Fix applet crashes on transparent user-set panel bg.
  * system tray: Fix hidden icons on image/transparent bg colour.
  * clock: Change size_reguest.
  * clock: Set a default width for calendarWindow.
  * clock: Set a margin_start for home icon.
  * clock: Set width_chars for time label.
  * GTK+ 3.18+ fix transparent default panel bg.
* Mon Jun 12 2017 sor.alexei@meowr.ru
- Update to version 1.18.3 (changes since 1.18.1):
  * status-notifier: Fix a crash on unknown signal name.
  * Fix build with gcc 4.9 (looks like it's in c89 mode by default).
  * Run dialogue: Add an option to reverse history view.
  * Run dialogue: Fix wrong history len with max size 1.
  * Run dialogue: Allow changing history size.
  * Run dialogue: Fix wrong history order.
  * status-notifier: Do not hide passive items.
  * Properly fit expanded panel to smaller screen size.
  * system-tray: Properly propagate orientation changes.
  * notification-area: Fix item orientation.
  * Fix moving applets between panels.
  * Fix l10n in panel launchers.
  * Status notifier: Follow the same menu theme as the rest of the
    panel.
  * clock: Properly handle visibility of the edit button.
  * clock: Move GtkButton in another horizontal GtkBox parent.
  * Fix launching Mozo from menubar/menu-button when menulibre
    isn't installed.
  * menu: Fix a crash when some .desktop file has an empty Icon
    field.
  * menu: Restore focus after closing popup menu of a menuitem.
  * menu: Restore focus after drag-n-dropping menuitem outside.
  * Some misc fixes and cleanups.
  * Update translations.
* Wed Apr  5 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Reenable workspace switcher wrapping.
  * status-notifier: Fix handling of icon-padding style property.
  * Simplify panel description shown when switching panels with the
    window manager.
  * status-notifier: Plug a memory leak.
  * Remove the deprecated sys/timeb.h header, as nothing uses it.
  * status-notifier-watcher: Allow re-registration of registered
    items.
  * Fix setup a custom icon.
  * Revert "Suppress the shutdown option in the panel if
    LTSP_CLIENT is set".
  * notification area: Fix memory leak sorting items.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require libmate-menu >= 1.10 and dconf >= 0.13.4.
  * Build: Require libmateweather and libmate-desktop >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Launchers: Add desktop actions support for additional launch
    options.
  * Menu applets: Add support for Menulibre menu editor, and prefer
    it over Mozo if both are installed.
  * Notification area: Add StatusNotifier support.
  * Fix lots of GTK+ deprecations and runtime warnings.
  * Don't spam accessible name changes when it is translated.
  * Some code cleanups.
  * Update translations.
* Wed Feb  8 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Clock applet: Mark a current day in the calendar.
  * Clock applet: Update a tooltip only when new text is different
    (fixes some OpenGL issues in fullscreen applications).
  * GTK+3: Stop the calendar window from jumping when
    expanding/folding locations.
  * GTK+3: Fix showing an icon at the mouse cursor on a launcher
    drag-n-drop.
  * GTK+3: Fix a heap of runtime warnings.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * GTK+3: Use GtkColorButton/GtkColorChooser in properties
    dialogue.
  * GTK+3: fix a lot of deprecations.
  * Some more fixes and cleanups.
  * Update translations.
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * Some fixes for opensuse.layout.
  * Some more fixes and cleanups.
  * Make distcheck use currently selected GTK+ version.
  * Update translations.
- Rebase mate-panel-layouts-suse.patch.
* Wed Jun  8 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix missing focus for panel widgets.
  * panel-widget: Add missing function declaration for
    GTK+ >= 3.18.
  * Add missing variable initialisation.
  * Restore correct applet finalising code.
  * Revert "Cancel background settings upon
    MatePanelAppletFrameDBus destruction.
  * na-try-child: Add missing include for GTK_Version_Check.
  * configure: Remove unused python-related directive.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Make max number of bookmarks in menu (before submenu is created)
    configurable via GSettings key
  * Some more fixes and cleanups.
  * Update translations.
  * Add Changelog generation.
* Tue Mar 29 2016 sor.alexei@meowr.ru
- Update to version 1.13.2:
  * GTK+3.18: Apply panelplug rework.
  * GTK+3.18/3.20: Move background handling toplevel.
  * GTK+3.18: Revert a hack not needed with moved bg code.
  * GTK+3.20: adjust CSS classes for WnckPager.
  * Use GTK+3.20 custom bg fixes only for > gtk+-3.18 and
    > glib-2.42.
  * GTK+3.20: Prevent transparent panel on BG change.
  * GTK+3.20: Fix custom BG change on applets.
  * Make MAX_ITEMS_OR_SUBMENU configurable.
  * GTK+3.20: Preserve default background.
  * GTK+3.20: Force custom BG drawing on applets.
  * GTK+3.20: Make custom background work on main panel.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Make icon size of menu items configurable via GSettings key.
  * Change default menubar icon size to 22px.
  * GTK+-3.20: A bunch of new css names and style classes are added.
  * GTK+-3.0 workspace-switcher: Remove switching workspace on
    scroll events, this is now done by WnckPager itself.
  * GTK+3: A lot of deprecations removal and fixes.
  * Fix some build warnings.
  * Icon chooser: Use a proper icon name for missing icons.
  * GTK+3: Fix ButtonWidget appearing as a thin line on creation.
  * Drop "Ubuntu hacks" (--enable-ubuntu build option) as Ubuntu
    dropped that stuff long ago.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Gtk3: More panel BG rendering bugfixes.
  * Add separate "Delete" button in reload applet dialog, and make
    "Don't Reload" button do what it says (it won't delete applet
    permanently now).
  * Gtk3 workspace-switcher: Add fallback colour.
  * GTK+3: Fix rendering of custom backgrounds with 3.18 and newer.
  * Gtk3: Don't use deprecated gtk_misc_set_alignment.
  * Drop MateConf migration script.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 1.12.2:
  * Drawer applet: Fix occasional stretching of drawer's panel over
    the entire screen.
  * Drawer applet: Fix occasional crash on applet removing.
  * GTK+3: Fix infinite loop with some themes.
  * Some more fixes.
* Wed Jan  6 2016 sor.alexei@meowr.ru
- Add missing XInput dependency.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Gtk3: fix background in some themes.
  * Some more fixes.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
- Add baselibs.conf.
- Add "Show Desktop" Software Updater applets to openSUSE layout.
* Wed Oct 28 2015 sor.alexei@meowr.ru
- Update to 1.11.1 (changes since 1.10.1):
  * Fix moving applets to another panel.
  * Run dialog: Make app description label unfocusable.
  * Fix positions of locked applets if screen resolution changed.
  * Gtk3: Add a style class for applets to follow panel-menu-bar.
  * Require XRandR 1.3.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Switch to org.gnome.SessionManager (used by action buttons).
  * Multiple GTK+3 fixes.
  * Some more fixes and cleanups.
- Remove mate-panel-no-locked-applet-position-change.patch: fixed
  upstream.
- Do not require nm-applet.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Add mate-panel-no-locked-applet-position-change.patch.
* Tue Sep 29 2015 sor.alexei@meowr.ru
- Add missing gschema compile in mate-panel package.
* Sat Jul 11 2015 sor.alexei@meowr.ru
- Update to version 1.10.1:
  * Fish and clock applets: help fixes.
  * Drawer applet: fix opening after adding applets to it.
  * Force Quit applet: fix desktop freezing with GTK+3.
  * Some more GTK+3 fixes.
  * Some code cleanup.
  * Translations updates.
* Sun May 24 2015 sor.alexei@meowr.ru
- Add mate-panel-layouts-suse.patch: correct missing elements.
- Spec cleanup.
* Mon May  4 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * No changes since version 1.9.90
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes release
* Wed Dec 10 2014 p.drouand@gmail.com
- Make lib subpackage own /usr/share/mate, as it's a standard
  directory for applet stuff
* Mon Dec  8 2014 p.drouand@gmail.com
- Update to version 1.9.4 (unstable)
  + Gtk3, Fix deprecated use of gdk pointer api
  + Gtk3, Port all GtkStyle to GtkStyleContext
  + Gtk3, Port gtk_rc_parse_string to GtkCssProvider
  + Gtk3, Several small fixes
  + Several more fixes from monsta
  + GDK_KEY_* is also in Gtk+2.24
  + showdesktop: Fix the size of the icon
  + clock: Check allocated size before creating the shadow pixbuf
  + applet: Disconnect show and deactivate menu signals before
    destroying the applet menu
  + Add a gtkimage with the current pixbuf to button-widget
  + Fix implicit declaration of function of gdk_x11_set_sm_client_id
  + panel-addto: Remove the vbox as it is redundant.
  + na: Fix handling of SYSTEM_TRAY_CANCEL_MESSAGE
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Use gtk icon cache instead of custom one
  + Several small
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + No changelog available
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + No changelog available
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Add needed macros required by any package which contains gsettings
  schemas
- Remove gsettings calling from main package
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Fix "Add to Panel" context menu with multiple monitors.
* Sat Jul 12 2014 p.drouand@gmail.com
- The layout is installed with "make install"; just apply it;
  Anyway, it was installed on the wrong directory
* Sat Apr 26 2014 p.drouand@gmail.com
- Apply installed layout provided by branding for initial installation
  with a gsettings override file
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
- Do not require hicolor-icon-theme; it's wrong
* Wed Feb 19 2014 p.drouand@gmail.com
- Update to version 1.7.90
  + added support for multiple layouts, stored in
    $(datadir)/mate-panel/layouts
  + added --layout parameter
  + add hook to support run dialog and main menu opening with metacity
  + switch to libwnck
  + use yelp-tools instead of mate-doc-utils
* Fri Feb 14 2014 p.drouand@gmail.com
- Update to version 1.7.2
  + fix various help documentation issues
  + fix GTK3 support
  + update translations
- Changes from version 1.7.1
  + better GTK3 support
  + bugs fix release
- Changes from version 1.7.0
  + initial GTK3 support
  + use yelp-tools instead of mate-doc-utils to build documentation
  + use libwnck instead of libmatewnck
- Replace libmatewnck-devel requirement with pkgconfig(libwnck-3.0)
- Replace pkgconfig(mate-doc-utils) requirement with yelp-tools
- Remove useless xz requirement
* Thu Oct 31 2013 p.drouand@gmail.com
- Fix libexecdir definition
* Fri Sep 20 2013 p.drouand@gmail.com
- Correct library subpackage group to System/Libraries
* Thu Sep 19 2013 johann.luce@wanadoo.fr
- Fix Obsoletes Problem for factory
* Mon Jul 15 2013 johann.luce@wanadoo.fr
- Update to version 1.6.1
  + fixes for make dist
  + fix g_type_init deprecation
  + fix indentation
  + remove mate-panelrc
  + fix a bug which made mate-panel --reset trigered a abrt alarm in fedora
    close issue https://github.com/mate-desktop/mate-panel/issues/111
  + libmate-panel-applet: Translate spanish comment
  + remove old mateconf script
  + save panel coordinates also if panel is expanded
  + allow to set panel orientation only for expanded panels
  + when the difference between timezones in the clock applet is less than 1 hour,
    an offset was not shown
  + add manpages for all binaries
  + wrap-workspaces option in workspace-switcher now persistent over sessions
  + modified the function workspace_switcher_applet_fill, which now correctly loads
    the wrap-workspaces GSchema entry.
  + clock: Allow users to set custom format in dconf-editor
  + fix panels issue when user has two separate X screens
  + fix MateConf convert file
  + fix vpath build of GIR
  + fix gtk-doc build
  + minor bugfix for the workspace switcher applet
  + fixed a bug when the toggle button belonging to wrap_workspaces is not toggled
  even though the value is TRUE on preferences dialog creation.
* Fri Apr 12 2013 p.drouand@gmail.com
- Add "Requires: gsettings-backend-dconf"; it's needed to save settings
  changes by user
* Mon Apr  8 2013 johann.luce@wanadoo.fr
- Add "Recommends:     %%{name}-lang" in spec file
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + update translations
* Sun Mar 17 2013 p.drouand@gmail.com
- Update to version 1.5.6:
  + Add transparency background function for workspace-switcher
  + Fix dconf minimum versions
  + Make GSettings schemas translatable
  + Add a wrap around option for workspace switcher:
  - a toggle button in the preferences (wrap_workspaces_toggle),
    a gboolean keeping track (wrap_workspaces)
  - another entry in the schema (gsettings)
  - and some minor code changes (which only affect the code when
    scrolling while on the last or first index)
* Fri Feb 22 2013 p.drouand@gmail.com
- Add branding subpackage and specific strings
  It is needed to allow to build an external branding
* Fri Feb  8 2013 p.drouand@gmail.com
- Update to version 1.5.5:
  + fix dependencies versions in configure
  + wncklet: Set orientation in window list
  + fix indentation
  + avoid double forking when launching apps it breaks
  + AC_CONFIG_HEADERS to please automake 1.13
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.4
  + fix mateweather units
  + wncklet: Fix window-list grouping preference
  + fix missing NULL pointer
- Remove mate-panel-1.5.3-null_pointer_fix.patch, upstreamed
* Thu Dec 20 2012 nmo.marques@gmail.com
- Add mate-panel-1.5.3-null_pointer_fix.patch; fix build,
  upstreamed
* Wed Dec 19 2012 nmo.marques@gmail.com
- Update to version 1.5.3
* Tue Nov 20 2012 nmo.marques@gmail.com
- Add NetworkManager-gnome to Requires, we want to make sure that
  we have installed the nm-applet.
* Tue Nov 20 2012 nmo.marques@gmail.com
- Remove conflicts for migration and change Requires to include
  gvfs-backends instead of gvfs-fuse.
* Sat Nov 10 2012 nmo.marques@gmail.com
- Add runtime dependency on gvfs-fuse; we need/want it. A few
  other packages could take it also, but mate-panel is a must, so
  it gets stuffed here.
* Sun Nov  4 2012 nmo.marques@gmail.com
- Add %%post/%%postun desktop database macros
* Fri Oct 19 2012 nmo.marques@gmail.com
- Update to 1.5.2.1
  + fix load background type at panel start
  + bump glib minimum to 2.26
* Tue Oct 16 2012 nmo.marques@gmail.com
- Update to 1.5.2
  + add --run-dialog option to open run dialog
  + fix build with dconf >= 0.13
- Remove mate-panel-1.5.1-fix_dconf_014.patch - upstreamed
* Mon Oct 15 2012 nmo.marques@gmail.com
- Add mate-panel-1.5.1-fix_dconf_014.patch: fix build issues for
  cases when dconf >= 0.14 (currently Factory). Cherry pick from
  upstream.
* Fri Oct 12 2012 nmo.marques@gmail.com
- Update to version 1.5.1
  + fix 64bit-portability-issues
  + fix dconf-requirements
  + fix mate-panel-applet-gsettings.c
- Remove mate-panel-rpmlintrc
* Thu Oct 11 2012 nmo.marques@gmail.com
- Update to version 1.5.0
  + update sources to final release version
* Wed Oct 10 2012 nmo.marques@gmail.com
- Update to version 1.4.9
  + THIS IS A TEST RELEASE
  + private test version
  + dropped all mateconf and matecomponent stuff in favor of DBus
    and gsettings
- Removed matecomponent and remove one library sub-package
- Split typelib into sub-spackage
- Obsolete old libraries and add conflicts to packages which might
  depend on them
* Sat Sep  8 2012 nmo.marques@gmail.com
- Fix loading of entries in post transaction and schemas install
* Sat Sep  8 2012 nmo.marques@gmail.com
- Exclude libmate-panel-applets-matecomponent.so module from main
  package for i386/i586/i686 where libexecdir and libdir match.
- Add %%fdupes macros for %%{_includedir}
* Sat Sep  8 2012 nmo.marques@gmail.com
- Update to version 1.4.0
  + fix build for 1140
- copypac to X11:MATE
  + minor cosmetic fixes
- Remove mate-panel-1.3.1-add_gmodules_to_linker.patch; fixed
* Sun Jun 17 2012 nmo.marques@gmail.com
- Update to version 1.3.1
- Add mate-panel-1.3.1-add_gmodules_to_linker.patch: add GMODULES
  to linker, reported upstream.
* Fri Feb  3 2012 fisiu@opensuse.org
- Initial package from version 1.2.0
